from django.contrib import admin
from enumfields.admin import EnumFieldListFilter
from arkindex.dataimport.models import DataImport, DataFile, Repository, Revision


class DataFileInline(admin.StackedInline):
    model = DataImport.files.through


class DataImportAdmin(admin.ModelAdmin):
    list_display = ('id', 'creator', 'corpus', 'state', 'mode')
    list_filter = [('state', EnumFieldListFilter), ('mode', EnumFieldListFilter)]
    fields = ('id', 'creator', 'corpus', 'state', 'mode', 'payload', 'root_id')
    readonly_fields = ('id', 'root_id', )
    inlines = [DataFileInline, ]


class DataFileAdmin(admin.ModelAdmin):
    list_display = ('id', 'name', 'corpus')
    list_filter = ('corpus', )
    fields = ('id', 'name', 'size', 'hash', 'content_type', 'corpus')
    readonly_fields = ('id', 'size', 'hash', )
    inlines = [DataFileInline, ]


class RevisionInline(admin.StackedInline):
    model = Revision


class RepositoryAdmin(admin.ModelAdmin):
    list_display = ('id', 'url', 'corpus')
    list_filter = ('corpus', )
    fields = ('id', 'url', 'corpus', 'hook_token', 'watched_branches')
    readonly_fields = ('id', )
    inlines = [RevisionInline, ]


admin.site.register(DataImport, DataImportAdmin)
admin.site.register(DataFile, DataFileAdmin)
admin.site.register(Repository, RepositoryAdmin)
