# Generated by Django 2.1 on 2018-08-21 09:17

from django.db import migrations, models
import hashlib

_cache = {}


def str_to_uuid(value):
    if value in _cache:
        return _cache[value]

    h = hashlib.md5(value.encode('utf-8')).hexdigest()
    _cache[value] = h
    return h


def convert(apps, schema_editor):
    '''
    Update all corpus ids by hashing their content towards a uuid
    '''

    DataImport = apps.get_model('dataimport', 'DataImport')
    DataFile = apps.get_model('dataimport', 'DataFile')
    Repository = apps.get_model('dataimport', 'Repository')

    for cls in (DataImport, DataFile, Repository):
        for x in cls.objects.all():
            x.corpus = str_to_uuid(x.corpus)
            x.save()


class Migration(migrations.Migration):

    dependencies = [
        ('dataimport', '0004_remove_tokens'),
    ]

    operations = [
        # Remove constraints
        migrations.AlterField(
            model_name='dataimport',
            name='corpus',
            field=models.CharField(max_length=250),
        ),
        migrations.AlterField(
            model_name='datafile',
            name='corpus',
            field=models.CharField(max_length=250),
        ),
        migrations.AlterField(
            model_name='repository',
            name='corpus',
            field=models.CharField(max_length=250),
        ),

        # Convert to uuid
        migrations.RunPython(convert),

        # Update fields to UUIDs
        migrations.AlterField(
            model_name='dataimport',
            name='corpus',
            field=models.UUIDField(),
        ),
        migrations.AlterField(
            model_name='datafile',
            name='corpus',
            field=models.UUIDField(),
        ),
        migrations.AlterField(
            model_name='repository',
            name='corpus',
            field=models.UUIDField(),
        ),
    ]
