from django.core.management import call_command
from arkindex.project.tests import RedisMockAPITestCase, FixtureMixin
from arkindex.dataimport.tasks import save_ml_results
from arkindex.documents.models import Page, Corpus, Element, ElementType


class TestTasks(FixtureMixin, RedisMockAPITestCase):
    """
    Test data imports tasks
    """
    def test_save_ml_results(self):
        corpus = Corpus.objects.create(name='test class')
        dog = Page.objects.create(corpus=corpus, name='A dog')
        cat = Page.objects.create(corpus=corpus, name='A cat')

        classification = {
            dog.id: {
                'classification': [
                    {
                        'label': 'dog',
                        'probability': 0.9,
                    }
                ],
                'text': 'This is a dog',
            },
            cat.id: {
                'classification': [
                    {
                        'label': 'cat',
                        'probability': 0.8,
                    }
                ],
                'text': 'This is a cat. meow',
            },
        }
        save_ml_results(classification)

        dog.refresh_from_db()
        self.assertEqual(dog.classification, [{
            'label': 'dog',
            'probability': 0.9,
        }])
        self.assertEqual(dog.text, 'This is a dog')

        cat.refresh_from_db()
        self.assertEqual(cat.classification, [{
            'label': 'cat',
            'probability': 0.8,
        }])
        self.assertEqual(cat.text, 'This is a cat. meow')

    def test_command(self):
        # No tasks at first
        self.assertEqual(self.redis.llen('celery'), 0)
        self.assertEqual(self.redis.llen('ml'), 0)

        # Test the admin command to start a volume analysis
        volume = Element.objects.filter(
            type=ElementType.Volume,
            corpus=self.corpus,
        ).first()
        self.assertIsNotNone(volume)
        call_command('analyze_ml', str(volume.id))

        # Check a ml task is started
        self.assertEqual(self.redis.llen('celery'), 0)
        self.assertEqual(self.redis.llen('ml'), 1)
