from django.views.generic import TemplateView, DetailView
from django.contrib.auth.mixins import LoginRequiredMixin
from arkindex.dataimport.models import DataImport, DataImportState, Repository


class DataImportsList(LoginRequiredMixin, TemplateView):
    """
    List data imports using Vue JS + API
    """
    template_name = 'dataimport/list.html'


class DataImportCreate(LoginRequiredMixin, TemplateView):
    """
    Create a new workflow
    """
    template_name = 'dataimport/new.html'


class DataImportConfig(LoginRequiredMixin, DetailView):
    """
    Configure a single data import workflow
    """
    template_name = 'dataimport/config.html'
    context_object_name = 'dataimport'

    def get_queryset(self):
        return DataImport.objects.filter(
            state__in=[DataImportState.Created, DataImportState.Configured],
            creator=self.request.user)


class DataImportStatus(LoginRequiredMixin, DetailView):
    """
    View a data import workflow's status
    """
    template_name = 'dataimport/status.html'
    context_object_name = 'dataimport'

    def get_queryset(self):
        return DataImport.objects.filter(creator=self.request.user).exclude(
            state__in=[DataImportState.Created, DataImportState.Configured],
        )


class DataImportFailures(LoginRequiredMixin, DetailView):
    """
    View a data import workflow's failures
    """
    template_name = 'dataimport/failures.html'
    context_object_name = 'dataimport'

    def get_queryset(self):
        return DataImport.objects.filter(creator=self.request.user).exclude(
            state__in=[DataImportState.Created, DataImportState.Configured],
        )


class DataFileList(LoginRequiredMixin, TemplateView):
    """
    View and manage uploaded files
    """
    template_name = 'dataimport/files.html'


class RepositoryList(LoginRequiredMixin, TemplateView):
    """
    Manage repositories
    """
    template_name = 'dataimport/repositories.html'


class RepositoryCreate(LoginRequiredMixin, TemplateView):
    """
    Create a new repository
    """
    template_name = 'dataimport/repository.new.html'


class RepositoryConfig(LoginRequiredMixin, DetailView):
    """
    Create a new repository
    """
    template_name = 'dataimport/repository.config.html'
    context_object_name = 'repo'

    def get_queryset(self):
        return Repository.objects.filter(credentials__user=self.request.user)
