# Generated by Django 2.0 on 2018-06-19 10:14

import django.contrib.postgres.fields
from django.db import migrations, models
import django.db.models.deletion
import uuid


BUILD_TREE = '''
create function build_tree(element_id uuid) returns table(id uuid, element_id uuid, path uuid[], ordering integer)
as $$

    with recursive tree as (
        -- Direct children for current element
        select l.child_id as element_id, array[l.parent_id]::uuid[] as path, l.order as ordering
        from documents_elementlink as l
        where parent_id = element_id

         union all

        -- Recursive !
        select l.child_id as element_id, tree.path || l.parent_id, l.order as ordering
        from documents_elementlink as l
        inner join tree on (l.parent_id = tree.element_id)
    )
    select uuid_generate_v4(), * from tree

$$ language sql;
'''


class Migration(migrations.Migration):

    dependencies = [
        ('documents', '0012_auto_20180619_0836'),
    ]

    operations = [
        migrations.CreateModel(
            name='ElementPath',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, primary_key=True, serialize=False)),
                ('path', django.contrib.postgres.fields.ArrayField(base_field=models.UUIDField(), size=None)),
                ('element', models.ForeignKey(
                    on_delete=django.db.models.deletion.DO_NOTHING,
                    related_name='paths',
                    to='documents.Element',
                )),
                ('ordering', models.PositiveIntegerField(default=0)),
            ],
        ),
        migrations.RunSQL(BUILD_TREE, 'drop function build_tree;'),
        migrations.RunSQL('drop materialized view if exists elements_children_cache;', ''),
        migrations.RunSQL('drop materialized view if exists elements_parents_cache;', ''),
        migrations.RunSQL('drop view if exists elements_children;', ''),
        migrations.RunSQL('drop view if exists elements_parents;', ''),
        migrations.DeleteModel(
            name='ElementParents',
        ),
        migrations.DeleteModel(
            name='ElementChildren',
        ),
    ]
