from django.urls import reverse
from arkindex.project.tests import FixtureAPITestCase
from rest_framework import status
from arkindex.documents.models import Page


class TestPageAnnotationListSerializer(FixtureAPITestCase):

    def test_normal_list(self):
        page = Page.objects.get(corpus=self.corpus, zone__image__path='img1')
        response = self.client.get(reverse('api:page-transcription-manifest', kwargs={'pk': page.id}))
        self.assertEqual(response.status_code, status.HTTP_200_OK)
        annotation_list = response.json()

        self.assertIn('@context', annotation_list)
        self.assertIn('@id', annotation_list)
        self.assertIn('@type', annotation_list)
        self.assertIn('resources', annotation_list)

        self.assertEqual(annotation_list['@type'], 'sc:AnnotationList')
        self.assertEqual(annotation_list['@context'], 'http://iiif.io/api/presentation/2/context.json')
        self.assertEqual(len(annotation_list['resources']), 3)

        for annotation in annotation_list['resources']:
            self.assertIn('@type', annotation)
            self.assertIn('@id', annotation)
            self.assertIn('on', annotation)
            self.assertIn('motivation', annotation)
            self.assertIn('resource', annotation)

            self.assertEqual(annotation['@type'], 'oa:Annotation')
            self.assertEqual(annotation['motivation'], 'sc:painting')

            resource = annotation['resource']
            self.assertIn('@id', resource)
            self.assertIn('@type', resource)
            self.assertIn('format', resource)
            self.assertIn('chars', resource)

            self.assertEqual(resource['format'], 'text/plain')
            self.assertEqual(resource['@type'], 'cnt:ContentAsText')
            self.assertIn(resource['chars'], ['PARIS', 'ROY', 'DATUM'])

    def test_empty_list(self):
        # An annotation list with nothing in it
        response = self.client.get(reverse('api:page-transcription-manifest', kwargs={
            'pk': Page.objects.get(corpus=self.corpus, zone__image__path='img6').id
        }))
        self.assertEqual(response.status_code, status.HTTP_200_OK)
        annotation_list = response.json()

        self.assertEqual(len(annotation_list['resources']), 0)


class TestPageActAnnotationListSerializer(FixtureAPITestCase):

    def test_normal_list(self):
        page = Page.objects.get(corpus=self.corpus, zone__image__path='img1')
        response = self.client.get(reverse('api:page-act-manifest', kwargs={'pk': page.id}))
        self.assertEqual(response.status_code, status.HTTP_200_OK)
        annotation_list = response.json()

        self.assertIn('@context', annotation_list)
        self.assertIn('@id', annotation_list)
        self.assertIn('@type', annotation_list)
        self.assertIn('resources', annotation_list)

        self.assertEqual(annotation_list['@type'], 'sc:AnnotationList')
        self.assertEqual(annotation_list['@context'], 'http://iiif.io/api/presentation/2/context.json')
        self.assertEqual(len(annotation_list['resources']), 2)

        for annotation in annotation_list['resources']:
            self.assertIn('@type', annotation)
            self.assertIn('@id', annotation)
            self.assertIn('on', annotation)
            self.assertIn('motivation', annotation)
            self.assertIn('resource', annotation)

            self.assertEqual(annotation['@type'], 'oa:Annotation')
            self.assertEqual(annotation['motivation'], 'sc:painting')

            resource = annotation['resource']
            self.assertIn('@id', resource)
            self.assertIn('@type', resource)
            self.assertIn('format', resource)
            self.assertIn('chars', resource)

            self.assertEqual(resource['format'], 'text/plain')
            self.assertEqual(resource['@type'], 'cnt:ContentAsText')
            self.assertIn(resource['chars'], ['Act 1', 'Act 2'])

    def test_empty_list(self):
        # An annotation list with nothing in it
        response = self.client.get(reverse('api:page-act-manifest', kwargs={
            'pk': Page.objects.get(corpus=self.corpus, zone__image__path='img6').id
        }))
        self.assertEqual(response.status_code, status.HTTP_200_OK)
        annotation_list = response.json()

        self.assertEqual(len(annotation_list['resources']), 0)
