from django.core.management import call_command
from arkindex.project.tests import FixtureTestCase
import io
import re


class TestTasks(FixtureTestCase):
    """Tests for telegraf reporting CLI"""

    def test_command(self):

        output = io.StringIO()
        call_command('telegraf', stdout=output)
        self.assertIsNotNone(output)

        # Parse output
        lines = list(filter(None, output.getvalue().split('\n')))
        self.assertEqual(len(lines), 3)

        regex = re.compile(r'^(\w+)(,[\w\-_,=]+)? ([\w\-_,=]+) (\d+)$')

        data = {}
        for line in lines:
            details = regex.search(line)
            self.assertIsNotNone(details)
            name, tags, values, t = details.groups()
            self.assertTrue(int(t) > 0)
            data[name] = {
                k: int(v)
                for k, v in re.findall(r'(\w+)=(\d+)', values)
            }
            data[name]["tags"] = {
                k: v
                for k, v in re.findall(r'(\w+)=([\w\-]+)', tags)
            } if tags else {}

        # Data tests
        self.assertEqual(data['transcriptions']['total'], 9)
        self.assertEqual(data['transcriptions']['tags'], {})
        self.assertEqual(data['pages']['total'], 6)
        self.assertEqual(data['pages']['with_transcriptions'], 3)
        self.assertEqual(data['pages']['tags'], {})
        self.assertEqual(data['corpus']['total'], 2)
        self.assertEqual(data['corpus']['with_transcriptions'], 1)
        self.assertDictEqual(data['corpus']['tags'], {'name': 'unit-tests'})
