from django.conf.urls import url
from django.views.generic.base import RedirectView

from arkindex.documents.api.elements import \
     ElementsList, RelatedElementsList, ElementRetrieve, ElementPages, ElementSurfaces, CorpusList, CorpusPages, \
     ActEdit, PageDetails, SurfaceDetails
from arkindex.documents.api.search import TranscriptionSearch, ActSearch
from arkindex.documents.api.transcriptions import TranscriptionCreate, TranscriptionBulk
from arkindex.documents.api.iiif import \
    VolumeManifest, ActManifest, PageAnnotationList, PageActAnnotationList, SurfaceAnnotationList, \
    TranscriptionSearchAnnotationList
from arkindex.dataimport.api import \
    DataImportsList, DataImportDetails, DataImportFailures, DataImportDemo, \
    DataFileList, DataFileRetrieve, DataFileUpload, \
    GitRepositoryImportHook, RepositoryList, AvailableRepositoriesList, RepositoryRetrieve, RepositoryStartImport
from arkindex.users.api import \
    ProvidersList, CredentialsList, CredentialsRetrieve, \
    UserRetrieve, UserCreate, UserEmailLogin, UserEmailVerification

api = [

    # Elements
    url(r'elements/(?P<pk>[\w\-]+)/pages/$',
        ElementPages.as_view(), name='volume-pages'),
    url(r'elements/(?P<pk>[\w\-]+)/surfaces/$',
        ElementSurfaces.as_view(), name='volume-surfaces'),
    url(r'elements/(?P<pk>[\w\-]+)/$',
        RelatedElementsList.as_view(), name='related-elements'),
    url(r'elements/$', ElementsList.as_view(), name='elements'),
    url(r'element/(?P<pk>[\w\-]+)/$', ElementRetrieve.as_view(), name='element-retrieve'),
    url(r'page/(?P<pk>[\w\-]+)/$', PageDetails.as_view(), name='page-details'),
    url(r'surface/(?P<pk>[\w\-]+)/$', SurfaceDetails.as_view(), name='surface-details'),
    url(r'corpus/$', CorpusList.as_view(), name='corpus'),
    url(r'corpus/(?P<pk>[\w\-]+)/pages/$',
        CorpusPages.as_view(), name='corpus-pages'),

    # Manifests
    url(r'^manifest/(?P<pk>[\w\-]+)/pages/$',
        VolumeManifest.as_view(),
        name='volume-manifest'),
    url(r'^manifest/(?P<pk>[\w\-]+)/act/$',
        ActManifest.as_view(),
        name='act-manifest'),
    url(r'^manifest/(?P<pk>[\w\-]+)/transcriptions/$',
        PageAnnotationList.as_view(),
        name='page-transcription-manifest'),
    url(r'^manifest/(?P<pk>[\w\-]+)/acts/$',
        PageActAnnotationList.as_view(),
        name='page-act-manifest'),
    url(r'^manifest/(?P<pk>[\w\-]+)/surface/$',
        SurfaceAnnotationList.as_view(),
        name='surface-manifest'),
    url(r'^manifest/(?P<pk>[\w\-]+)/search/$',
        TranscriptionSearchAnnotationList.as_view(),
        name='ts-search-manifest'),

    # Placeholder URLs for IIIF IDs
    url(r'^manifest/(?P<pk>[\w\-]+)/sequence/$',
        RedirectView.as_view(pattern_name='api:volume-manifest', permanent=False),
        name='sequence-manifest'),
    url(r'^manifest/(?P<pk>[\w\-]+)/canvas/$',
        RedirectView.as_view(pattern_name='api:page-act-manifest', permanent=False),
        name='canvas-manifest'),
    url(r'^manifest/(?P<page_pk>[\w\-]+)/transcriptions/(?P<transcription_pk>[\w\-]+)/$',
        RedirectView.as_view(pattern_name='api:page-transcription-manifest', permanent=False),
        name='transcription-manifest'),
    url(r'^manifest/(?P<page_pk>[\w\-]+)/surfaces/(?P<surface_pk>[\w\-]+)/$',
        RedirectView.as_view(pattern_name='api:page-act-manifest', permanent=False),
        name='surface-manifest'),

    # Search transcriptions
    url(r'^transcriptions/$', TranscriptionSearch.as_view(), name='transcription-search'),
    url(r'^acts/$', ActSearch.as_view(), name='act-search'),

    # Edit acts
    url(r'^act/(?P<pk>[\w\-]+)/$', ActEdit.as_view(), name='act-edit'),

    # Ingest transcriptions
    url(r'^transcription/$', TranscriptionCreate.as_view(), name='transcription-create'),
    url(r'^transcription/bulk/$', TranscriptionBulk.as_view(), name='transcription-bulk'),

    # Import workflows
    url(r'^imports/$', DataImportsList.as_view(), name='import-list'),
    url(r'^imports/repos/$', RepositoryList.as_view(), name='repository-list'),
    url(r'^imports/repos/(?P<pk>[\w\-]+)/$', RepositoryRetrieve.as_view(), name='repository-retrieve'),
    url(r'^imports/repos/(?P<pk>[\w\-]+)/start/$', RepositoryStartImport.as_view(), name='repository-import'),
    url(r'^imports/repos/search/(?P<pk>[\w\-]+)/$',
        AvailableRepositoriesList.as_view(),
        name='available-repositories'),
    url(r'^imports/(?P<pk>[\w\-]+)/$', DataImportDetails.as_view(), name='import-details'),
    url(r'^imports/(?P<pk>[\w\-]+)/failures/$', DataImportFailures.as_view(), name='import-failures'),
    url(r'^imports/demo/(?P<pk>[\w\-]+)/$', DataImportDemo.as_view(), name='import-demo'),
    url(r'^imports/files/(?P<pk>[\w\-]+)/$', DataFileList.as_view(), name='file-list'),
    url(r'^imports/file/(?P<pk>[\w\-]+)/$', DataFileRetrieve.as_view(), name='file-retrieve'),
    url(r'^imports/upload/(?P<pk>[\w\-]+)/$', DataFileUpload.as_view(), name='file-upload'),
    url(r'^imports/hook/(?P<pk>[\w\-]+)/$', GitRepositoryImportHook.as_view(), name='import-hook'),

    # Manage OAuth integrations
    url(r'^oauth/providers/$', ProvidersList.as_view(), name='providers-list'),
    url(r'^oauth/credentials/$', CredentialsList.as_view(), name='credentials-list'),
    url(r'^oauth/credentials/(?P<pk>[\w\-]+)/$', CredentialsRetrieve.as_view(), name='credentials-retrieve'),

    # Authentication
    url(r'^user/$', UserRetrieve.as_view(), name='user-retrieve'),
    url(r'^user/new/$', UserCreate.as_view(), name='user-new'),
    url(r'^user/login/$', UserEmailLogin.as_view(), name='user-login'),
    url(r'^user/token/$', UserEmailVerification.as_view(), name='user-token'),
]
