from django.conf import settings
from rest_framework import serializers
from rest_framework.reverse import reverse
from enum import Enum


class EnumField(serializers.ChoiceField):
    """
    Serializes an enum field into a JSON value
    """

    def __init__(self, enum, *args, **kwargs):
        assert issubclass(enum, Enum) or not enum
        self.enum = enum
        choices = [(item.value, item.name) for item in self.enum]
        super().__init__(choices, *args, **kwargs)

    def to_representation(self, obj):
        return obj.value

    def to_internal_value(self, data):
        assert self.enum is not None, "No enum set on EnumField"
        return self.enum(data)


class ViewerURLField(serializers.HyperlinkedIdentityField):
    '''
    Build an absolute url to view this element into Mirador (or something else)
    '''
    def get_url(self, obj, view_name, request, format):
        return '{mirador}?manifest={act_url}'.format(
            mirador=settings.MIRADOR_URI,
            act_url=reverse(view_name, args=(obj.id, ), request=request, format=format),
        )
