from django.test import TestCase
from django.contrib.auth.models import AnonymousUser
from arkindex.documents.models import Corpus
from arkindex.users.models import User


class TestACL(TestCase):
    '''
    Test Corpus ACL
    '''

    def setUp(self):
        self.anon = AnonymousUser()
        self.admin = User.objects.create_superuser('admin@address.com', 'P4$5w0Rd')
        self.user = User.objects.create_user('user@address.com', 'P4$5w0Rd')

        self.corpus_public = Corpus.objects.create(name='A Public', public=True)
        self.corpus_private = Corpus.objects.create(name='B Private')
        self.user.corpus_right.create(corpus=self.corpus_private, user=self.user, can_write=True)
        self.corpus_hidden = Corpus.objects.create(name='C Hidden')

    def test_anon(self):
        # An anonymous user has only access to public
        self.assertQuerysetEqual(
            Corpus.objects.readable(self.anon),
            [self.corpus_public.id],
            transform=lambda x: x.id,
        )

    def test_user(self):
        # An anonymous user has access to public & private
        self.assertFalse(self.user.is_admin)
        self.assertQuerysetEqual(
            Corpus.objects.readable(self.user),
            [self.corpus_public.id, self.corpus_private.id],
            transform=lambda x: x.id,
        )

    def test_admin(self):
        # An admin has access to all
        self.assertTrue(self.admin.is_admin)
        self.assertQuerysetEqual(
            Corpus.objects.readable(self.admin),
            Corpus.objects.order_by('name').values_list('id', flat=True),
            transform=lambda x: x.id,
        )
